==> hermes-2.5.1.60.tar.gz: hermes-2.5.1.60/spec/apis/dmo/management_areas_spec.rb <==
require 'rails_helper'

module Hermes
  require [Hermes::Engine.root, %w[lib hermes tools specs]].flatten.join('/')

  ACCEPTABLE_PARAMS = %w[
    name
    code
    lessor_id
  ].freeze

  describe Api::Dmo::ManagementAreasController, :type => :api do
    routes {Hermes::Engine.routes}
    include Devise::Test::ControllerHelpers
    include JwtAuthHelper
    let!(:responsible) { create(:user, roles: ['Administrator']) }
    let!(:user) { create(:user) }
    let!(:lessor) { create(:lessor, siret: '00000000000000', readers: [user.id.to_s]) }
    let!(:lessor2) { create(:lessor, siret: '00000000000000', readers: [responsible.id.to_s]) }
    
    let(:management_area1) { create(:management_area, name: 'test', lessor_id: lessor2.id.to_s) }
    let(:management_area2) { create(:management_area, name: 'test', lessor_id: lessor2.id.to_s) }
    let(:management_area3) { create(:management_area, name: 'test', lessor_id: lessor2.id.to_s) }
    let(:management_area4) { create(:management_area, name: 'test', lessor_id: lessor.id.to_s) }
    
    # Bug bizarre ou les management_areas ne sont pas enregistrée en base 
    before :each do
      management_area1.save
      management_area2.save
      management_area3.save
      management_area4.save
    end

    describe 'POST /management_areas' do
      describe 'Create as admin' do
        before :each do
          authenticated_header(request, responsible)
          post 'create', {
              data: {
                  attributes: {
                      name: 'test'
                  }
              }
          }
        end
        it 'returns status code 201' do

          expect(response).to have_http_status(201)
          expect(json['data']['attributes']['code']).to eq('ALSSG-4')
        end
      end

      describe 'Create as user without lessor_id' do
        before :each do
          authenticated_header(request, user)
          post 'create', {
              data: {
                  attributes: {
                      name: 'test'
                  }
              }
          }
        end
        it 'returns error when no lessor_id' do
          expect(response).to have_http_status(422)
        end
      end

      describe 'Create as user with lessor_id' do
        before :each do
          authenticated_header(request, user)
          post 'create', {
              data: {
                  attributes: {
                      name: 'test',
                      lessor_id: lessor.id.to_s
                  }
              }
          }
        end
        it 'returns 201' do
          expect(response).to have_http_status(201)
          expect(json['data']['attributes']['code']).to eq('ALSSG-4')
        end
      end
    end

    describe 'GET /management_areas' do
      describe 'as admin' do 
        before :each do
          authenticated_header(request, responsible)
          get 'index'
        end
        it 'returns status code 200' do
          expect(response).to have_http_status(200)
        end
        it 'returns a valid json' do
          expect(json).not_to be_empty
          expect(json['data'].length).to eq(4)
        end
      end
      describe 'as user' do 
        before :each do
          authenticated_header(request, user)
          get 'index'
        end
        it 'returns status code 200' do
          expect(response).to have_http_status(200)
        end
        it 'returns a valid json' do
          expect(json).not_to be_empty
          expect(json['data'].length).to eq(1)
        end
      end
    end

    describe 'GET /management_areas/:id' do
      describe 'verif it work' do
        before :each do
          authenticated_header(request, user)
          get 'show', {id: management_area4.id}
        end
        it 'returns status code 200' do
          expect(response).to have_http_status(200)
        end
        it 'returns a valid json' do
          expect(json).not_to be_empty
        end
      end

      describe 'verif it work not work with a non authorized user' do

        before :each do
          authenticated_header(request, user)
          get 'show', {id: management_area1.id}
        end
        it 'returns status code 404' do
          expect(response).to have_http_status(404)
        end
      end
    end


    describe 'DELETE /management_areas/:id' do
      before :each do
        authenticated_header(request, responsible)

        delete 'destroy', {
            id: management_area1.id.to_s
        }
      end
      it 'returns status code 204' do
        expect(response).to have_http_status(204)
      end
    end

  end
end

==> hermes-5.3.0.10.tar.gz: hermes-5.3.0.10/spec/apis/dmo/management_areas_spec.rb <==
require 'rails_helper'

module Hermes
  require [Hermes::Engine.root, %w[lib hermes tools specs]].flatten.join('/')

  ACCEPTABLE_PARAMS = %w[
    name
    code
    lessor_id
  ].freeze

  describe Api::Dmo::ManagementAreasController, :type => :api do
    routes {Hermes::Engine.routes}
    include Devise::Test::ControllerHelpers
    include JwtAuthHelper
    let!(:responsible) { create(:user, roles: ['Administrator']) }
    let!(:user) { create(:user) }
    let!(:lessor) { create(:lessor, siret: '00000000000000', readers: [user.id.to_s]) }
    let!(:lessor2) { create(:lessor, siret: '00000000000000', readers: [responsible.id.to_s]) }
    
    let!(:management_area1) { create(:management_area, name: 'name1', lessor_id: lessor2.id.to_s) }
    let!(:management_area2) { create(:management_area, name: 'name2', lessor_id: lessor2.id.to_s) }
    let!(:management_area3) { create(:management_area, name: 'test3', lessor_id: lessor2.id.to_s) }
    let!(:management_area4) { create(:management_area, name: 'test4', lessor_id: lessor.id.to_s) }
    
    describe 'POST /management_areas' do
      describe 'Create as admin' do
        before :each do
          authenticated_header(request, responsible)
          post 'create', {
              data: {
                  attributes: {
                      name: 'test'
                  }
              }
          }
        end
        it 'returns status code 201' do

          expect(response).to have_http_status(201)
          expect(json['data']['attributes']['code']).to eq('ALSSG-4')
        end
      end

      describe 'Create as user without lessor_id' do
        before :each do
          authenticated_header(request, user)
          post 'create', {
              data: {
                  attributes: {
                      name: 'test'
                  }
              }
          }
        end
        it 'returns error when no lessor_id' do
          expect(response).to have_http_status(422)
        end
      end

      describe 'Create as user with lessor_id' do
        before :each do
          authenticated_header(request, user)
          post 'create', {
              data: {
                  attributes: {
                      name: 'test',
                      lessor_id: lessor.id.to_s
                  }
              }
          }
        end
        it 'returns 201' do
          expect(response).to have_http_status(201)
          expect(json['data']['attributes']['code']).to eq('ALSSG-4')
        end
      end
    end

    describe 'GET /management_areas' do
      describe 'as admin' do 
        before :each do
          authenticated_header(request, responsible)
          get 'index'
        end
        it 'returns status code 200' do
          expect(response).to have_http_status(200)
        end
        it 'returns a valid json' do
          expect(json).not_to be_empty
          expect(json['data'].length).to eq(4)
        end
      end
      describe 'as user' do 
        before :each do
          authenticated_header(request, user)
          get 'index'
        end
        it 'returns status code 200' do
          expect(response).to have_http_status(200)
        end
        it 'returns a valid json' do
          expect(json).not_to be_empty
          expect(json['data'].length).to eq(1)
        end
      end

      describe 'regex on name' do 
        before :each do
          authenticated_header(request, responsible)
          get 'index', {name: {"$regex": "test" }}
        end
        it 'returns a valid json' do
          expect(response).to have_http_status(200)
          expect(json).not_to be_empty
          expect(json['data'].length).to eq(2)
        end
      end

    end

    describe 'GET /management_areas/:id' do
      describe 'verif it work' do
        before :each do
          authenticated_header(request, user)
          get 'show', {id: management_area4.id}
        end
        it 'returns status code 200' do
          expect(response).to have_http_status(200)
        end
        it 'returns a valid json' do
          expect(json).not_to be_empty
        end
      end

      describe 'verif it work not work with a non authorized user' do

        before :each do
          authenticated_header(request, user)
          get 'show', {id: management_area1.id}
        end
        it 'returns status code 404' do
          expect(response).to have_http_status(404)
        end
      end
    end


    describe 'DELETE /management_areas/:id' do
      before :each do
        authenticated_header(request, responsible)

        delete 'destroy', {
            id: management_area1.id.to_s
        }
      end
      it 'returns status code 204' do
        expect(response).to have_http_status(204)
      end
    end

  end
end
